@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.metastore_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -85,6 +96,8 @@ class DataprocMetastoreAsyncClient:
     parse_network_path = staticmethod(DataprocMetastoreClient.parse_network_path)
     service_path = staticmethod(DataprocMetastoreClient.service_path)
     parse_service_path = staticmethod(DataprocMetastoreClient.parse_service_path)
+    subnetwork_path = staticmethod(DataprocMetastoreClient.subnetwork_path)
+    parse_subnetwork_path = staticmethod(DataprocMetastoreClient.parse_subnetwork_path)
     common_billing_account_path = staticmethod(
         DataprocMetastoreClient.common_billing_account_path
     )
@@ -195,9 +208,9 @@ class DataprocMetastoreAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DataprocMetastoreTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the dataproc metastore client.
@@ -241,11 +254,11 @@ class DataprocMetastoreAsyncClient:
 
     async def list_services(
         self,
-        request: Union[metastore.ListServicesRequest, dict] = None,
+        request: Optional[Union[metastore.ListServicesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesAsyncPager:
         r"""Lists services in a project and location.
@@ -278,7 +291,7 @@ class DataprocMetastoreAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.ListServicesRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.ListServicesRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.ListServices][google.cloud.metastore.v1.DataprocMetastore.ListServices].
             parent (:class:`str`):
@@ -358,11 +371,11 @@ class DataprocMetastoreAsyncClient:
 
     async def get_service(
         self,
-        request: Union[metastore.GetServiceRequest, dict] = None,
+        request: Optional[Union[metastore.GetServiceRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.Service:
         r"""Gets the details of a single service.
@@ -394,7 +407,7 @@ class DataprocMetastoreAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.GetServiceRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.GetServiceRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.GetService][google.cloud.metastore.v1.DataprocMetastore.GetService].
             name (:class:`str`):
@@ -462,13 +475,13 @@ class DataprocMetastoreAsyncClient:
 
     async def create_service(
         self,
-        request: Union[metastore.CreateServiceRequest, dict] = None,
+        request: Optional[Union[metastore.CreateServiceRequest, dict]] = None,
         *,
-        parent: str = None,
-        service: metastore.Service = None,
-        service_id: str = None,
+        parent: Optional[str] = None,
+        service: Optional[metastore.Service] = None,
+        service_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a metastore service in a project and
@@ -500,13 +513,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.CreateServiceRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.CreateServiceRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.CreateService][google.cloud.metastore.v1.DataprocMetastore.CreateService].
             parent (:class:`str`):
@@ -613,12 +626,12 @@ class DataprocMetastoreAsyncClient:
 
     async def update_service(
         self,
-        request: Union[metastore.UpdateServiceRequest, dict] = None,
+        request: Optional[Union[metastore.UpdateServiceRequest, dict]] = None,
         *,
-        service: metastore.Service = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        service: Optional[metastore.Service] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single service.
@@ -647,13 +660,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.UpdateServiceRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.UpdateServiceRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.UpdateService][google.cloud.metastore.v1.DataprocMetastore.UpdateService].
             service (:class:`google.cloud.metastore_v1.types.Service`):
@@ -748,11 +761,11 @@ class DataprocMetastoreAsyncClient:
 
     async def delete_service(
         self,
-        request: Union[metastore.DeleteServiceRequest, dict] = None,
+        request: Optional[Union[metastore.DeleteServiceRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single service.
@@ -782,13 +795,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.DeleteServiceRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.DeleteServiceRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.DeleteService][google.cloud.metastore.v1.DataprocMetastore.DeleteService].
             name (:class:`str`):
@@ -874,11 +887,11 @@ class DataprocMetastoreAsyncClient:
 
     async def list_metadata_imports(
         self,
-        request: Union[metastore.ListMetadataImportsRequest, dict] = None,
+        request: Optional[Union[metastore.ListMetadataImportsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMetadataImportsAsyncPager:
         r"""Lists imports in a service.
@@ -911,7 +924,7 @@ class DataprocMetastoreAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.ListMetadataImportsRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.ListMetadataImportsRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1.DataprocMetastore.ListMetadataImports].
             parent (:class:`str`):
@@ -991,11 +1004,11 @@ class DataprocMetastoreAsyncClient:
 
     async def get_metadata_import(
         self,
-        request: Union[metastore.GetMetadataImportRequest, dict] = None,
+        request: Optional[Union[metastore.GetMetadataImportRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.MetadataImport:
         r"""Gets details of a single import.
@@ -1027,7 +1040,7 @@ class DataprocMetastoreAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.GetMetadataImportRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.GetMetadataImportRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.GetMetadataImport][google.cloud.metastore.v1.DataprocMetastore.GetMetadataImport].
             name (:class:`str`):
@@ -1095,13 +1108,13 @@ class DataprocMetastoreAsyncClient:
 
     async def create_metadata_import(
         self,
-        request: Union[metastore.CreateMetadataImportRequest, dict] = None,
+        request: Optional[Union[metastore.CreateMetadataImportRequest, dict]] = None,
         *,
-        parent: str = None,
-        metadata_import: metastore.MetadataImport = None,
-        metadata_import_id: str = None,
+        parent: Optional[str] = None,
+        metadata_import: Optional[metastore.MetadataImport] = None,
+        metadata_import_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new MetadataImport in a given project and
@@ -1133,13 +1146,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.CreateMetadataImportRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.CreateMetadataImportRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.CreateMetadataImport][google.cloud.metastore.v1.DataprocMetastore.CreateMetadataImport].
             parent (:class:`str`):
@@ -1245,12 +1258,12 @@ class DataprocMetastoreAsyncClient:
 
     async def update_metadata_import(
         self,
-        request: Union[metastore.UpdateMetadataImportRequest, dict] = None,
+        request: Optional[Union[metastore.UpdateMetadataImportRequest, dict]] = None,
         *,
-        metadata_import: metastore.MetadataImport = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        metadata_import: Optional[metastore.MetadataImport] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates a single import.
@@ -1281,13 +1294,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.UpdateMetadataImportRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.UpdateMetadataImportRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.UpdateMetadataImport][google.cloud.metastore.v1.DataprocMetastore.UpdateMetadataImport].
             metadata_import (:class:`google.cloud.metastore_v1.types.MetadataImport`):
@@ -1382,10 +1395,10 @@ class DataprocMetastoreAsyncClient:
 
     async def export_metadata(
         self,
-        request: Union[metastore.ExportMetadataRequest, dict] = None,
+        request: Optional[Union[metastore.ExportMetadataRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Exports metadata from a service.
@@ -1416,13 +1429,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.ExportMetadataRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.ExportMetadataRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1.DataprocMetastore.ExportMetadata].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1478,12 +1491,12 @@ class DataprocMetastoreAsyncClient:
 
     async def restore_service(
         self,
-        request: Union[metastore.RestoreServiceRequest, dict] = None,
+        request: Optional[Union[metastore.RestoreServiceRequest, dict]] = None,
         *,
-        service: str = None,
-        backup: str = None,
+        service: Optional[str] = None,
+        backup: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Restores a service from a backup.
@@ -1514,13 +1527,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.RestoreServiceRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.RestoreServiceRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.Restore][].
             service (:class:`str`):
@@ -1610,11 +1623,11 @@ class DataprocMetastoreAsyncClient:
 
     async def list_backups(
         self,
-        request: Union[metastore.ListBackupsRequest, dict] = None,
+        request: Optional[Union[metastore.ListBackupsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBackupsAsyncPager:
         r"""Lists backups in a service.
@@ -1647,7 +1660,7 @@ class DataprocMetastoreAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.ListBackupsRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.ListBackupsRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.ListBackups][google.cloud.metastore.v1.DataprocMetastore.ListBackups].
             parent (:class:`str`):
@@ -1727,11 +1740,11 @@ class DataprocMetastoreAsyncClient:
 
     async def get_backup(
         self,
-        request: Union[metastore.GetBackupRequest, dict] = None,
+        request: Optional[Union[metastore.GetBackupRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> metastore.Backup:
         r"""Gets details of a single backup.
@@ -1763,7 +1776,7 @@ class DataprocMetastoreAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.GetBackupRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.GetBackupRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.GetBackup][google.cloud.metastore.v1.DataprocMetastore.GetBackup].
             name (:class:`str`):
@@ -1829,13 +1842,13 @@ class DataprocMetastoreAsyncClient:
 
     async def create_backup(
         self,
-        request: Union[metastore.CreateBackupRequest, dict] = None,
+        request: Optional[Union[metastore.CreateBackupRequest, dict]] = None,
         *,
-        parent: str = None,
-        backup: metastore.Backup = None,
-        backup_id: str = None,
+        parent: Optional[str] = None,
+        backup: Optional[metastore.Backup] = None,
+        backup_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new backup in a given project and location.
@@ -1866,13 +1879,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.CreateBackupRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.CreateBackupRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.CreateBackup][google.cloud.metastore.v1.DataprocMetastore.CreateBackup].
             parent (:class:`str`):
@@ -1976,11 +1989,11 @@ class DataprocMetastoreAsyncClient:
 
     async def delete_backup(
         self,
-        request: Union[metastore.DeleteBackupRequest, dict] = None,
+        request: Optional[Union[metastore.DeleteBackupRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single backup.
@@ -2010,13 +2023,13 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.metastore_v1.types.DeleteBackupRequest, dict]):
+            request (Optional[Union[google.cloud.metastore_v1.types.DeleteBackupRequest, dict]]):
                 The request object. Request message for
                 [DataprocMetastore.DeleteBackup][google.cloud.metastore.v1.DataprocMetastore.DeleteBackup].
             name (:class:`str`):
@@ -2107,14 +2120,9 @@ class DataprocMetastoreAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-metastore",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DataprocMetastoreAsyncClient",)
