@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
@@ -27,6 +29,9 @@ __protobuf__ = proto.module(
         "HiveMetastoreConfig",
         "KerberosConfig",
         "Secret",
+        "EncryptionConfig",
+        "NetworkConfig",
+        "TelemetryConfig",
         "MetadataManagementActivity",
         "MetadataImport",
         "MetadataExport",
@@ -71,7 +76,7 @@ class Service(proto.Message):
             This field is a member of `oneof`_ ``metastore_config``.
         name (str):
             Immutable. The relative resource name of the metastore
-            service, of the form:
+            service, in the following format:
 
             ``projects/{project_number}/locations/{location_id}/services/{service_id}``.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
@@ -80,7 +85,7 @@ class Service(proto.Message):
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time when the metastore
             service was last updated.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             User-defined labels for the metastore
             service.
         network (str):
@@ -112,7 +117,9 @@ class Service(proto.Message):
             The one hour maintenance window of the
             metastore service. This specifies when the
             service can be restarted for maintenance
-            purposes in UTC time.
+            purposes in UTC time. Maintenance window is not
+            needed for services with the SPANNER database
+            type.
         uid (str):
             Output only. The globally unique resource
             identifier of the metastore service.
@@ -122,6 +129,20 @@ class Service(proto.Message):
         release_channel (google.cloud.metastore_v1.types.Service.ReleaseChannel):
             Immutable. The release channel of the service. If
             unspecified, defaults to ``STABLE``.
+        encryption_config (google.cloud.metastore_v1.types.EncryptionConfig):
+            Immutable. Information used to configure the
+            Dataproc Metastore service to encrypt customer
+            data at rest. Cannot be updated.
+        network_config (google.cloud.metastore_v1.types.NetworkConfig):
+            The configuration specifying the network
+            settings for the Dataproc Metastore service.
+        database_type (google.cloud.metastore_v1.types.Service.DatabaseType):
+            Immutable. The database type that the
+            Metastore service stores its data.
+        telemetry_config (google.cloud.metastore_v1.types.TelemetryConfig):
+            The configuration specifying telemetry settings for the
+            Dataproc Metastore service. If unspecified defaults to
+            ``JSON``.
     """
 
     class State(proto.Enum):
@@ -151,80 +172,106 @@ class Service(proto.Message):
         CANARY = 1
         STABLE = 2
 
-    hive_metastore_config = proto.Field(
+    class DatabaseType(proto.Enum):
+        r"""The backend database type for the metastore service."""
+        DATABASE_TYPE_UNSPECIFIED = 0
+        MYSQL = 1
+        SPANNER = 2
+
+    hive_metastore_config: "HiveMetastoreConfig" = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="metastore_config",
         message="HiveMetastoreConfig",
     )
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    network = proto.Field(
+    network: str = proto.Field(
         proto.STRING,
         number=7,
     )
-    endpoint_uri = proto.Field(
+    endpoint_uri: str = proto.Field(
         proto.STRING,
         number=8,
     )
-    port = proto.Field(
+    port: int = proto.Field(
         proto.INT32,
         number=9,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=10,
         enum=State,
     )
-    state_message = proto.Field(
+    state_message: str = proto.Field(
         proto.STRING,
         number=11,
     )
-    artifact_gcs_uri = proto.Field(
+    artifact_gcs_uri: str = proto.Field(
         proto.STRING,
         number=12,
     )
-    tier = proto.Field(
+    tier: Tier = proto.Field(
         proto.ENUM,
         number=13,
         enum=Tier,
     )
-    maintenance_window = proto.Field(
+    maintenance_window: "MaintenanceWindow" = proto.Field(
         proto.MESSAGE,
         number=15,
         message="MaintenanceWindow",
     )
-    uid = proto.Field(
+    uid: str = proto.Field(
         proto.STRING,
         number=16,
     )
-    metadata_management_activity = proto.Field(
+    metadata_management_activity: "MetadataManagementActivity" = proto.Field(
         proto.MESSAGE,
         number=17,
         message="MetadataManagementActivity",
     )
-    release_channel = proto.Field(
+    release_channel: ReleaseChannel = proto.Field(
         proto.ENUM,
         number=19,
         enum=ReleaseChannel,
     )
+    encryption_config: "EncryptionConfig" = proto.Field(
+        proto.MESSAGE,
+        number=20,
+        message="EncryptionConfig",
+    )
+    network_config: "NetworkConfig" = proto.Field(
+        proto.MESSAGE,
+        number=21,
+        message="NetworkConfig",
+    )
+    database_type: DatabaseType = proto.Field(
+        proto.ENUM,
+        number=22,
+        enum=DatabaseType,
+    )
+    telemetry_config: "TelemetryConfig" = proto.Field(
+        proto.MESSAGE,
+        number=23,
+        message="TelemetryConfig",
+    )
 
 
 class MaintenanceWindow(proto.Message):
@@ -239,12 +286,12 @@ class MaintenanceWindow(proto.Message):
             The day of week, when the window starts.
     """
 
-    hour_of_day = proto.Field(
+    hour_of_day: wrappers_pb2.Int32Value = proto.Field(
         proto.MESSAGE,
         number=1,
         message=wrappers_pb2.Int32Value,
     )
-    day_of_week = proto.Field(
+    day_of_week: dayofweek_pb2.DayOfWeek = proto.Field(
         proto.ENUM,
         number=2,
         enum=dayofweek_pb2.DayOfWeek,
@@ -258,11 +305,13 @@ class HiveMetastoreConfig(proto.Message):
     Attributes:
         version (str):
             Immutable. The Hive metastore schema version.
-        config_overrides (Mapping[str, str]):
+        config_overrides (MutableMapping[str, str]):
             A mapping of Hive metastore configuration key-value pairs to
             apply to the Hive metastore (configured in
             ``hive-site.xml``). The mappings override system defaults
-            (some keys cannot be overridden).
+            (some keys cannot be overridden). These overrides are also
+            applied to auxiliary versions and can be further customized
+            in the auxiliary version's ``AuxiliaryVersionConfig``.
         kerberos_config (google.cloud.metastore_v1.types.KerberosConfig):
             Information used to configure the Hive metastore service as
             a service principal in a Kerberos realm. To disable
@@ -272,16 +321,16 @@ class HiveMetastoreConfig(proto.Message):
             the request's ``service``.
     """
 
-    version = proto.Field(
+    version: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    config_overrides = proto.MapField(
+    config_overrides: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
     )
-    kerberos_config = proto.Field(
+    kerberos_config: "KerberosConfig" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="KerberosConfig",
@@ -307,16 +356,16 @@ class KerberosConfig(proto.Message):
             does not need to be named krb5.conf explicitly.
     """
 
-    keytab = proto.Field(
+    keytab: "Secret" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="Secret",
     )
-    principal = proto.Field(
+    principal: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    krb5_config_gcs_uri = proto.Field(
+    krb5_config_gcs_uri: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -337,31 +386,122 @@ class Secret(proto.Message):
             This field is a member of `oneof`_ ``value``.
     """
 
-    cloud_secret = proto.Field(
+    cloud_secret: str = proto.Field(
         proto.STRING,
         number=2,
         oneof="value",
     )
 
 
+class EncryptionConfig(proto.Message):
+    r"""Encryption settings for the service.
+
+    Attributes:
+        kms_key (str):
+            The fully qualified customer provided Cloud KMS key name to
+            use for customer data encryption, in the following form:
+
+            ``projects/{project_number}/locations/{location_id}/keyRings/{key_ring_id}/cryptoKeys/{crypto_key_id}``.
+    """
+
+    kms_key: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class NetworkConfig(proto.Message):
+    r"""Network configuration for the Dataproc Metastore service.
+
+    Attributes:
+        consumers (MutableSequence[google.cloud.metastore_v1.types.NetworkConfig.Consumer]):
+            Immutable. The consumer-side network
+            configuration for the Dataproc Metastore
+            instance.
+    """
+
+    class Consumer(proto.Message):
+        r"""Contains information of the customer's network
+        configurations.
+
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+        Attributes:
+            subnetwork (str):
+                Immutable. The subnetwork of the customer project from which
+                an IP address is reserved and used as the Dataproc Metastore
+                service's endpoint. It is accessible to hosts in the subnet
+                and to all hosts in a subnet in the same region and same
+                network. There must be at least one IP address available in
+                the subnet's primary range. The subnet is specified in the
+                following form:
+
+                ``projects/{project_number}/regions/{region_id}/subnetworks/{subnetwork_id}``
+
+                This field is a member of `oneof`_ ``vpc_resource``.
+            endpoint_uri (str):
+                Output only. The URI of the endpoint used to
+                access the metastore service.
+        """
+
+        subnetwork: str = proto.Field(
+            proto.STRING,
+            number=1,
+            oneof="vpc_resource",
+        )
+        endpoint_uri: str = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+
+    consumers: MutableSequence[Consumer] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=Consumer,
+    )
+
+
+class TelemetryConfig(proto.Message):
+    r"""Telemetry Configuration for the Dataproc Metastore service.
+
+    Attributes:
+        log_format (google.cloud.metastore_v1.types.TelemetryConfig.LogFormat):
+            The output format of the Dataproc Metastore
+            service's logs.
+    """
+
+    class LogFormat(proto.Enum):
+        r""""""
+        LOG_FORMAT_UNSPECIFIED = 0
+        LEGACY = 1
+        JSON = 2
+
+    log_format: LogFormat = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=LogFormat,
+    )
+
+
 class MetadataManagementActivity(proto.Message):
     r"""The metadata management activities of the metastore service.
 
     Attributes:
-        metadata_exports (Sequence[google.cloud.metastore_v1.types.MetadataExport]):
+        metadata_exports (MutableSequence[google.cloud.metastore_v1.types.MetadataExport]):
             Output only. The latest metadata exports of
             the metastore service.
-        restores (Sequence[google.cloud.metastore_v1.types.Restore]):
+        restores (MutableSequence[google.cloud.metastore_v1.types.Restore]):
             Output only. The latest restores of the
             metastore service.
     """
 
-    metadata_exports = proto.RepeatedField(
+    metadata_exports: MutableSequence["MetadataExport"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="MetadataExport",
     )
-    restores = proto.RepeatedField(
+    restores: MutableSequence["Restore"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="Restore",
@@ -429,51 +569,51 @@ class MetadataImport(proto.Message):
             DATABASE_TYPE_UNSPECIFIED = 0
             MYSQL = 1
 
-        database_type = proto.Field(
+        database_type: "MetadataImport.DatabaseDump.DatabaseType" = proto.Field(
             proto.ENUM,
             number=1,
             enum="MetadataImport.DatabaseDump.DatabaseType",
         )
-        gcs_uri = proto.Field(
+        gcs_uri: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        type_ = proto.Field(
+        type_: "DatabaseDumpSpec.Type" = proto.Field(
             proto.ENUM,
             number=4,
             enum="DatabaseDumpSpec.Type",
         )
 
-    database_dump = proto.Field(
+    database_dump: DatabaseDump = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="metadata",
         message=DatabaseDump,
     )
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         message=timestamp_pb2.Timestamp,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=5,
         enum=State,
@@ -512,27 +652,27 @@ class MetadataExport(proto.Message):
         FAILED = 3
         CANCELLED = 4
 
-    destination_gcs_uri = proto.Field(
+    destination_gcs_uri: str = proto.Field(
         proto.STRING,
         number=4,
         oneof="destination",
     )
-    start_time = proto.Field(
+    start_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=3,
         enum=State,
     )
-    database_dump_type = proto.Field(
+    database_dump_type: "DatabaseDumpSpec.Type" = proto.Field(
         proto.ENUM,
         number=5,
         enum="DatabaseDumpSpec.Type",
@@ -561,7 +701,7 @@ class Backup(proto.Message):
             the time of backup.
         description (str):
             The description of the backup.
-        restoring_services (Sequence[str]):
+        restoring_services (MutableSequence[str]):
             Output only. Services that are restoring from
             the backup.
     """
@@ -575,35 +715,35 @@ class Backup(proto.Message):
         FAILED = 4
         RESTORING = 5
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=4,
         enum=State,
     )
-    service_revision = proto.Field(
+    service_revision: "Service" = proto.Field(
         proto.MESSAGE,
         number=5,
         message="Service",
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    restoring_services = proto.RepeatedField(
+    restoring_services: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=7,
     )
@@ -648,31 +788,31 @@ class Restore(proto.Message):
         FULL = 1
         METADATA_ONLY = 2
 
-    start_time = proto.Field(
+    start_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=3,
         enum=State,
     )
-    backup = proto.Field(
+    backup: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    type_ = proto.Field(
+    type_: RestoreType = proto.Field(
         proto.ENUM,
         number=5,
         enum=RestoreType,
     )
-    details = proto.Field(
+    details: str = proto.Field(
         proto.STRING,
         number=6,
     )
@@ -715,23 +855,23 @@ class ListServicesRequest(proto.Message):
             order.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -742,13 +882,13 @@ class ListServicesResponse(proto.Message):
     [DataprocMetastore.ListServices][google.cloud.metastore.v1.DataprocMetastore.ListServices].
 
     Attributes:
-        services (Sequence[google.cloud.metastore_v1.types.Service]):
+        services (MutableSequence[google.cloud.metastore_v1.types.Service]):
             The services in the specified location.
         next_page_token (str):
             A token that can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -756,16 +896,16 @@ class ListServicesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    services = proto.RepeatedField(
+    services: MutableSequence["Service"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Service",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -783,7 +923,7 @@ class GetServiceRequest(proto.Message):
             ``projects/{project_number}/locations/{location_id}/services/{service_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -829,20 +969,20 @@ class CreateServiceRequest(proto.Message):
             supported.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    service_id = proto.Field(
+    service_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    service = proto.Field(
+    service: "Service" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Service",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -884,17 +1024,17 @@ class UpdateServiceRequest(proto.Message):
             supported.
     """
 
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=1,
         message=field_mask_pb2.FieldMask,
     )
-    service = proto.Field(
+    service: "Service" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Service",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -928,11 +1068,11 @@ class DeleteServiceRequest(proto.Message):
             supported.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -975,23 +1115,23 @@ class ListMetadataImportsRequest(proto.Message):
             order.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -1002,13 +1142,13 @@ class ListMetadataImportsResponse(proto.Message):
     [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1.DataprocMetastore.ListMetadataImports].
 
     Attributes:
-        metadata_imports (Sequence[google.cloud.metastore_v1.types.MetadataImport]):
+        metadata_imports (MutableSequence[google.cloud.metastore_v1.types.MetadataImport]):
             The imports in the specified service.
         next_page_token (str):
             A token that can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -1016,16 +1156,16 @@ class ListMetadataImportsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    metadata_imports = proto.RepeatedField(
+    metadata_imports: MutableSequence["MetadataImport"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="MetadataImport",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -1043,7 +1183,7 @@ class GetMetadataImportRequest(proto.Message):
             ``projects/{project_number}/locations/{location_id}/services/{service_id}/metadataImports/{import_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -1089,20 +1229,20 @@ class CreateMetadataImportRequest(proto.Message):
             supported.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    metadata_import_id = proto.Field(
+    metadata_import_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    metadata_import = proto.Field(
+    metadata_import: "MetadataImport" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="MetadataImport",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -1144,17 +1284,17 @@ class UpdateMetadataImportRequest(proto.Message):
             supported.
     """
 
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=1,
         message=field_mask_pb2.FieldMask,
     )
-    metadata_import = proto.Field(
+    metadata_import: "MetadataImport" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="MetadataImport",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -1197,23 +1337,23 @@ class ListBackupsRequest(proto.Message):
             order.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -1224,13 +1364,13 @@ class ListBackupsResponse(proto.Message):
     [DataprocMetastore.ListBackups][google.cloud.metastore.v1.DataprocMetastore.ListBackups].
 
     Attributes:
-        backups (Sequence[google.cloud.metastore_v1.types.Backup]):
+        backups (MutableSequence[google.cloud.metastore_v1.types.Backup]):
             The backups of the specified service.
         next_page_token (str):
             A token that can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -1238,16 +1378,16 @@ class ListBackupsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    backups = proto.RepeatedField(
+    backups: MutableSequence["Backup"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Backup",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -1265,7 +1405,7 @@ class GetBackupRequest(proto.Message):
             ``projects/{project_number}/locations/{location_id}/services/{service_id}/backups/{backup_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -1311,20 +1451,20 @@ class CreateBackupRequest(proto.Message):
             supported.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    backup_id = proto.Field(
+    backup_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    backup = proto.Field(
+    backup: "Backup" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Backup",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -1358,11 +1498,11 @@ class DeleteBackupRequest(proto.Message):
             supported.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -1409,20 +1549,20 @@ class ExportMetadataRequest(proto.Message):
             defaults to ``MYSQL``.
     """
 
-    destination_gcs_folder = proto.Field(
+    destination_gcs_folder: str = proto.Field(
         proto.STRING,
         number=2,
         oneof="destination",
     )
-    service = proto.Field(
+    service: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    database_dump_type = proto.Field(
+    database_dump_type: "DatabaseDumpSpec.Type" = proto.Field(
         proto.ENUM,
         number=4,
         enum="DatabaseDumpSpec.Type",
@@ -1464,20 +1604,20 @@ class RestoreServiceRequest(proto.Message):
             supported.
     """
 
-    service = proto.Field(
+    service: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    backup = proto.Field(
+    backup: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    restore_type = proto.Field(
+    restore_type: "Restore.RestoreType" = proto.Field(
         proto.ENUM,
         number=3,
         enum="Restore.RestoreType",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -1513,33 +1653,33 @@ class OperationMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    target = proto.Field(
+    target: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    verb = proto.Field(
+    verb: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    status_message = proto.Field(
+    status_message: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    requested_cancellation = proto.Field(
+    requested_cancellation: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
-    api_version = proto.Field(
+    api_version: str = proto.Field(
         proto.STRING,
         number=7,
     )
@@ -1549,7 +1689,7 @@ class LocationMetadata(proto.Message):
     r"""Metadata about the service in a location.
 
     Attributes:
-        supported_hive_metastore_versions (Sequence[google.cloud.metastore_v1.types.LocationMetadata.HiveMetastoreVersion]):
+        supported_hive_metastore_versions (MutableSequence[google.cloud.metastore_v1.types.LocationMetadata.HiveMetastoreVersion]):
             The versions of Hive Metastore that can be used when
             creating a new metastore service in this location. The
             server guarantees that exactly one ``HiveMetastoreVersion``
@@ -1570,16 +1710,18 @@ class LocationMetadata(proto.Message):
                 that omits the ``version``.
         """
 
-        version = proto.Field(
+        version: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        is_default = proto.Field(
+        is_default: bool = proto.Field(
             proto.BOOL,
             number=2,
         )
 
-    supported_hive_metastore_versions = proto.RepeatedField(
+    supported_hive_metastore_versions: MutableSequence[
+        HiveMetastoreVersion
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=HiveMetastoreVersion,
