@@ -13,12 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.metastore import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.dataproc_metastore import (
     DataprocMetastoreAsyncClient,
     DataprocMetastoreClient,
 )
+from .services.dataproc_metastore_federation import (
+    DataprocMetastoreFederationAsyncClient,
+    DataprocMetastoreFederationClient,
+)
 from .types.metastore import (
+    AlterMetadataResourceLocationRequest,
+    AlterMetadataResourceLocationResponse,
     AuxiliaryVersionConfig,
     Backup,
     CreateBackupRequest,
@@ -49,32 +59,58 @@ from .types.metastore import (
     MetadataImport,
     MetadataIntegration,
     MetadataManagementActivity,
+    MoveTableToDatabaseRequest,
+    MoveTableToDatabaseResponse,
     NetworkConfig,
     OperationMetadata,
+    QueryMetadataRequest,
+    QueryMetadataResponse,
+    RemoveIamPolicyRequest,
+    RemoveIamPolicyResponse,
     Restore,
     RestoreServiceRequest,
     Secret,
     Service,
+    TelemetryConfig,
     UpdateMetadataImportRequest,
     UpdateServiceRequest,
 )
+from .types.metastore_federation import (
+    BackendMetastore,
+    CreateFederationRequest,
+    DeleteFederationRequest,
+    Federation,
+    GetFederationRequest,
+    ListFederationsRequest,
+    ListFederationsResponse,
+    UpdateFederationRequest,
+)
 
 __all__ = (
     "DataprocMetastoreAsyncClient",
+    "DataprocMetastoreFederationAsyncClient",
+    "AlterMetadataResourceLocationRequest",
+    "AlterMetadataResourceLocationResponse",
     "AuxiliaryVersionConfig",
+    "BackendMetastore",
     "Backup",
     "CreateBackupRequest",
+    "CreateFederationRequest",
     "CreateMetadataImportRequest",
     "CreateServiceRequest",
     "DataCatalogConfig",
     "DatabaseDumpSpec",
     "DataplexConfig",
     "DataprocMetastoreClient",
+    "DataprocMetastoreFederationClient",
     "DeleteBackupRequest",
+    "DeleteFederationRequest",
     "DeleteServiceRequest",
     "EncryptionConfig",
     "ExportMetadataRequest",
+    "Federation",
     "GetBackupRequest",
+    "GetFederationRequest",
     "GetMetadataImportRequest",
     "GetServiceRequest",
     "HiveMetastoreConfig",
@@ -82,6 +118,8 @@ __all__ = (
     "Lake",
     "ListBackupsRequest",
     "ListBackupsResponse",
+    "ListFederationsRequest",
+    "ListFederationsResponse",
     "ListMetadataImportsRequest",
     "ListMetadataImportsResponse",
     "ListServicesRequest",
@@ -92,12 +130,20 @@ __all__ = (
     "MetadataImport",
     "MetadataIntegration",
     "MetadataManagementActivity",
+    "MoveTableToDatabaseRequest",
+    "MoveTableToDatabaseResponse",
     "NetworkConfig",
     "OperationMetadata",
+    "QueryMetadataRequest",
+    "QueryMetadataResponse",
+    "RemoveIamPolicyRequest",
+    "RemoveIamPolicyResponse",
     "Restore",
     "RestoreServiceRequest",
     "Secret",
     "Service",
+    "TelemetryConfig",
+    "UpdateFederationRequest",
     "UpdateMetadataImportRequest",
     "UpdateServiceRequest",
 )
